package org.eclipse.jdt.internal.compiler.lookup;

import org.eclipse.jdt.internal.compiler.ast.ASTNode;
import org.eclipse.jdt.internal.compiler.ast.ExpressionContext;

public interface InvocationSite
{
    public abstract TypeBinding[] genericTypeArguments();
    
    public abstract boolean isSuperAccess();
    
    public abstract boolean isQualifiedSuper();
    
    public abstract boolean isTypeAccess();
    
    public abstract void setActualReceiverType(ReferenceBinding p0);
    
    public abstract void setDepth(int p0);
    
    public abstract void setFieldIndex(int p0);
    
    public abstract int sourceEnd();
    
    public abstract int sourceStart();
    
    public abstract TypeBinding invocationTargetType();
    
    public abstract boolean receiverIsImplicitThis();
    
    public abstract boolean checkingPotentialCompatibility();
    
    public abstract void acceptPotentiallyCompatibleMethods(MethodBinding[] p0);
    
    public abstract InferenceContext18 freshInferenceContext(Scope p0);
    
    public abstract ExpressionContext getExpressionContext();
    
    public static class EmptyWithAstNode implements InvocationSite
    {
        ASTNode node;
        
        public EmptyWithAstNode(ASTNode node) {
            this.node = node;
        }
        
        @Override
        public TypeBinding[] genericTypeArguments() {
            return null;
        }
        
        @Override
        public boolean isSuperAccess() {
            return false;
        }
        
        @Override
        public boolean isTypeAccess() {
            return false;
        }
        
        @Override
        public void setActualReceiverType(ReferenceBinding receiverType) {
        }
        
        @Override
        public void setDepth(int depth) {
        }
        
        @Override
        public void setFieldIndex(int depth) {
        }
        
        @Override
        public int sourceEnd() {
            return this.node.sourceEnd;
        }
        
        @Override
        public int sourceStart() {
            return this.node.sourceStart;
        }
        
        @Override
        public TypeBinding invocationTargetType() {
            return null;
        }
        
        @Override
        public boolean receiverIsImplicitThis() {
            return false;
        }
        
        @Override
        public InferenceContext18 freshInferenceContext(Scope scope) {
            return null;
        }
        
        @Override
        public ExpressionContext getExpressionContext() {
            return ExpressionContext.VANILLA_CONTEXT;
        }
        
        @Override
        public boolean isQualifiedSuper() {
            return false;
        }
        
        @Override
        public boolean checkingPotentialCompatibility() {
            return false;
        }
        
        @Override
        public void acceptPotentiallyCompatibleMethods(MethodBinding[] methods) {
        }
    }
}
